<?php

namespace Drupal\facets_range_input\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\facets\FacetInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Ajax\HtmlCommand;


/**
 * Class RangeInputForm.
 */
class RangeInputForm extends FormBase {

  /**
   * @var FacetInterface $facet
   */
  protected $facet;

  /**
   * Class constructor.
   */
  public function __construct(FacetInterface $facet) {
    $this->facet = $facet;
  }
  
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'range_input_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#attributes']['class'] = [
        'js-facets-widget',
        'js-facets-' . $this->facet->getWidget()['type'],
    ];
    
    $form['#theme'] = 'facets_range_input_form';

    
    $active = $this->facet->getActiveItems();
    
    $inputFields = [
        'minimum' => [
            'id' => 'minimum',
            'title' => 'Minimum',
            'short' => 'Min',
        ],
        'maximum' => [
            'id' => 'maximum',
            'title' => 'Maximum',
            'short' => 'Max',
        ]
    ];
    if(isset($active[0])) {
      $inputFields['minimum']['active'] = $active[0][0];
      $inputFields['maximum']['active'] = $active[0][1];
    }
    
    foreach($inputFields as $field) {
      $form[$field['id']] = [
        '#type' => 'number',
        //'#title' => $this->t($field['title']),
        '#placeholder' => $this->t($field['short'] . ' ($)'),
        '#field_suffix' => $this->t('<div id="' . $this->facet->id() . '_' . $field['id'] . '_validation"></div>'),
        '#maxlength' => 10,
        '#size' => 10,
        '#weight' => '0',
        '#attributes' => [
            'id' => $this->facet->id() . '_' . $field['id'],
            'facet-range-input-input-id' => $field['id'],
            'facet-range-input-input-title' => $field['title'],
            'facet-range-input-facet-id' => $this->facet->id(),
        ],
        '#required' => TRUE,
      ];
    }
    $form['validationContainer'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => ['validationContainer'],
        'class' => [
            'facets-range-input-valid-range',
        ]
      ],
    ];

    $form['apply'] = [
      '#type' => 'submit',
      '#value' => $this->t('Apply'),
      '#ajax' => [
        'callback' => '::ajaxSubmit',
        'event' => 'click',
      ],
      
    ];
    
    
    $form['#cache'] = ['max-age' => 0];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    //parent::validateForm($form, $form_state);
    
    if(empty($form_state->getValue('minimum'))) {
      $min = 0;
    } else {
      $min = $form_state->getValue('minimum');
    }

    if(empty($form_state->getValue('maximum'))) {
      return FALSE;
    } else {
      $max = $form_state->getValue('maximum');
    }
    if($min >= $max) {
      return FALSE;
    } else {
      return TRUE;
    }
    
//    
    
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
    

  }
  
  public function ajaxSubmit(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    
    if($this->validateForm($form,$form_state, $response) == TRUE) {

      $payload = [
          'minimum' => $form_state->getValue('minimum'),
          'maximum' => $form_state->getValue('maximum'),
          'facetId' => $this->facet->id(),
      ];

      $jQuerySelector = '[name=' . $this->facet->id() . '_apply_filters]';

      $response->addCommand(new InvokeCommand(NULL, 'facetsRangeInputFilter', [$payload]));

      return $response;
    } else {
      
      $invalidRangeText = 'Please enter a valid range';
      $response->addCommand(new HtmlCommand('#validationContainer', $invalidRangeText));
      return $response;
    }
  }

}
