<?php

namespace Drupal\facets_range_input\Plugin\Facets\widget;

use Drupal\facets\FacetInterface;
use Drupal\facets\Result\ResultInterface;
use Drupal\facets\Widget\WidgetPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;



/**
 * A simple widget class that returns a simple array of the facet results.
 *
 * @FacetsWidget(
 *   id = "range_input",
 *   label = @Translation("Range Input"),
 *   description = @Translation("A widget that creates two input forms for min and max to create a range."),
 * )
 */
class RangeInputWidget extends  WidgetPluginBase {
  
  

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'prefix' => '',
      'suffix' => '',
    ] + parent::defaultConfiguration();
  }
  
  public function build(FacetInterface $facet) {
    $build = parent::build($facet);
    
    $results = $facet->getResults();
    ksort($results);

    // Make sure there are results before building up the facet settings, otherwise just return the build since we can't do anything to it without a placeholder URL...and there's no results to facet anyway.
    if(empty($results)) {
      return $build;
    } else {
      // Get only the first result
      $firstResult = reset($results);
      // Build a generic URL with placeholders.
      $url = $firstResult->getUrl()->toString();

      $build['#attached']['library'][] = 'facets_range_input/rangeInput';


      // Is there an active range set up already?
      $active = $facet->getActiveItems();

      $facet_settings = &$build['#attached']['drupalSettings']['facets']['rangeInput'][$facet->id()];
      // Set the min value or placeholder.
      if(isset($active[0][0])) {
        $facet_settings['currentValues']['minimum'] = $active[0][0];
      }
      // Set the max value or placeholder.
      if(isset($active[0][1])) {
        $facet_settings['currentValues']['maximum'] = $active[0][1];
      }

      $facet_settings['facetId'] = $facet->id();
      $facet_settings['url'] = $url;
      unset($facet_settings['value']);


      $build['#theme'] = 'facets_range_input';


      $rangeInputForm = new \Drupal\facets_range_input\Form\RangeInputForm($facet);

      $form = \Drupal::formBuilder()->getForm($rangeInputForm);

      $build['form'] = $form;

      $build['type'] = [
        '#markup' => $this->t(str_replace('_', '-', $facet->getWidget()['type'])),
      ];
      return $build;
    }

  }
  
  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state, FacetInterface $facet) {
    $config = $this->getConfiguration();
    $form = parent::buildConfigurationForm($form, $form_state, $facet);
    
    $form['prefix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Value prefix'),
      '#size' => 5,
      '#default_value' => $config['prefix'],
    ];

    $form['suffix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Value suffix'),
      '#size' => 5,
      '#default_value' => $config['suffix'],
    ];
    
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getQueryType() {
    return 'range';
  }
  
//  public function buildWidgitForm(FacetInterface $facet) {
//    $active = $facet->getActiveItems();
//
//    $form['range_validation'] = [
//      '#type' => 'container',
//      '#attributes' => [
//          'id' => $facet->id() . '_range_validation',
//      ]
//    ];
//    $inputFields = [
//        'minimum' => [
//            'id' => 'minimum',
//            'title' => 'Minimum',
//            //'active' => $active[0][0],
//        ],
//        'maximum' => [
//            'id' => 'maximum',
//            'title' => 'Maximum',
//            //'active' => $active[0][1],
//        ]
//    ];
//    if(isset($active[0])) {
//      $inputFields['minimum']['active'] = $active[0][0];
//      $inputFields['maximum']['active'] = $active[0][1];
//    }
//    
//    foreach($inputFields as $field) {
//      $form[$field['id']] = [
//        '#type' => 'textfield',
//        '#title' => $this->t($field['title']),
//        '#placeholder' => $this->t('$'),
//        '#field_suffix' => $this->t('<div id="' . $facet->id() . '_' . $field['id'] . '_validation"></div>'),
//        '#maxlength' => 10,
//        '#size' => 10,
//        '#weight' => '0',
//        '#attributes' => [
//            'id' => $facet->id() . '_' . $field['id'],
//            'facet-range-input-input-id' => $field['id'],
//            'facet-range-input-input-title' => $field['title'],
//            'facet-range-input-facet-id' => $facet->id(),
//        ],
//        '#required' => TRUE,
//      ];
//      if(isset($field['active'])) {
//        $form[$field['id']]['#value'] = $field['active'];
//      }
//    }
//
//    $form['submit'] = [
//      '#type' => 'submit',
//      '#value' => $this->t('Apply'),
//      '#attributes' => [
//          'id' => $facet->id() . '_apply_filter',
//          'name' => $this->t(''),
//      ],
////      '#ajax' => [
////          'callback' => [$this, 'ajaxSubmitForm'],
////          //'event' => 'click',
////      ],
//    ];
//    
//    return $form;
//  }
  
}
